@@ -51,6 +51,14 @@ class Api:
         )
         return url
 
+    def respond_notebook(self):
+        display(
+            Markdown(
+                "Response Set as Notebook !",
+                metadata={"naas_api": True, "naas_type": t_notebook},
+            )
+        )
+
     def respond_file(self, path):
         naas_type = mimetypes.guess_type(os.path.abspath(path))[0]
         data = {"path": os.path.abspath(path)}
