@@ -11,10 +11,13 @@ import json
 import os
 from IPython.core.display import display, HTML
 import ipywidgets as widgets
+import copy
 
 
 class Manager:
     __local_api = f'http://localhost:{os.environ.get("NAAS_RUNNER_PORT", 5000)}'
+    __error_manager_busy = "Manager look busy, try to reload your machine"
+    __error_manager_reject = "Manager refused your request, reason :"
     __base_ftp_path = None
     __public_url = None
     __jup_user = None
@@ -53,9 +56,9 @@ class Manager:
             r = requests.get(f"{self.__local_api}/{t_job}")
             naas_data = r.json()
         except ConnectionError:
-            print("Manager look busy, try to reload your machine")
+            print(self.__error_manager_busy)
         except requests.HTTPError as e:
-            print("Manager refused your request, reason :", e)
+            print(self.__error_manager_reject, e)
         return naas_data
 
     def get_value(self, path, obj_type):
@@ -188,6 +191,8 @@ class Manager:
             )
         if os.path.exists(path):
             os.remove(path)
+        else:
+            raise Exception(f"File {path} not Found")
 
     def get_prod(self, path):
         self.__copy_file_in_dev(path)
@@ -245,37 +250,43 @@ class Manager:
 
     def add_prod(self, obj, silent):
         if "type" in obj and "path" in obj and "params" in obj and "value" in obj:
+            new_obj = copy.copy(obj)
             dev_path = obj.get("path")
-            obj["path"] = self.get_prod_path(obj.get("path"))
-            obj["status"] = t_add
             self.__copy_file_in_prod(dev_path)
+            new_obj["path"] = self.get_prod_path(dev_path)
+            new_obj["status"] = t_add
             try:
-                r = requests.post(f"{self.__local_api}/{t_job}", json=obj)
+                r = requests.post(f"{self.__local_api}/{t_job}", data=new_obj)
+                r.raise_for_status()
+                res = r.json()
                 if not silent:
-                    print(f'{r.json()["status"]} ==> {obj}')
+                    print(f'{res["status"]} ==> {new_obj}')
             except ConnectionError:
-                print("Manager look busy, try to reload your machine")
+                print(self.__error_manager_busy)
             except requests.HTTPError as e:
-                print("Manager refused your request, reason :", e)
-            return obj
+                print(self.__error_manager_reject, e)
+            return new_obj
         else:
-            raise Exception(
-                'obj should have all keys ("type","path","params","value" )'
-            )
+            raise Exception('obj should have all keys ("type","path","params","value")')
 
     def del_prod(self, obj, silent):
         if "type" in obj and "path" in obj:
-            obj["path"] = self.get_prod_path(obj.get("path"))
-            obj["status"] = t_delete
-            self.__del_file_in_prod(obj["path"])
+            new_obj = copy.copy(obj)
+            new_obj["path"] = self.get_prod_path(obj.get("path"))
+            new_obj["params"] = {}
+            new_obj["value"] = None
+            new_obj["status"] = t_delete
+            self.__del_file_in_prod(new_obj["path"])
             try:
-                r = requests.post(f"{self.__local_api}/{t_job}", json=obj)
+                r = requests.post(f"{self.__local_api}/{t_job}", json=new_obj)
+                r.raise_for_status()
+                res = r.json()
                 if not silent:
-                    print(f'{r.json()["status"]} ==> {obj}')
+                    print(f'{res[0]["status"]} ==> {new_obj}')
             except ConnectionError:
-                print("Manager look busy, try to reload your machine")
+                print(self.__error_manager_busy)
             except requests.HTTPError as e:
-                print("Manager refused your request, reason :", e)
-            return obj
+                print(self.__error_manager_reject, e)
+            return new_obj
         else:
             raise Exception('obj should have keys ("type","path")')
