@@ -13,15 +13,12 @@ from sanic_openapi import swagger_blueprint
 from .logger import Logger
 from .proxy import escape_kubernet
 from .jobs import Jobs
-
-# from naas.__version__ import __version__
 from sanic import Sanic
 import sentry_sdk
 import asyncio
 import getpass
 import uuid
 import os
-import json
 import sys
 import errno
 import nest_asyncio
@@ -30,38 +27,25 @@ import nest_asyncio
 asyncio.set_event_loop_policy(None)
 nest_asyncio.apply()
 
-__version__ = "0.5.4"
+__version__ = "0.5.16"
 
 
 class Runner:
-    # Declare semaphore variable
-    __name = "naas_runner"
     __naas_folder = ".naas"
-    __tasks_sem = None
     # Declare path variable
     __path_lib_files = os.path.dirname(os.path.abspath(__file__))
     __path_user_files = None
     __port = 5000
-    __single_user_api_path = None
     __html_files = "html"
-    __assets_files = "assets"
     __manager_index = "manager.html"
-    __log_filename = "logs.csv"
-    __tasks_files = "jobs.json"
-    __info_file = "info.json"
     __app = None
     __nb = None
-    __http_server = None
     __notif = None
     __jobs = None
     __scheduler = None
-    __daemon = None
-    __sentry = None
     __logger = None
-    __testing = False
-    tz = None
-    user = None
     __shell_user = None
+    __tz = None
     public_url = None
     proxy_url = None
 
@@ -85,7 +69,6 @@ class Runner:
         self.__path_manager_index = os.path.join(
             self.__path_html_files, self.__manager_index
         )
-        self.__path_pidfile = os.path.join(self.__path_naas_files, f"{self.__name}.pid")
 
     def __main(self, debug=True):
         self.init_app()
@@ -93,17 +76,6 @@ class Runner:
         self.__logger.info({"id": uid, "type": t_main, "status": "start API"})
         self.__app.run(host="0.0.0.0", port=self.__port, debug=debug, access_log=debug)
 
-    def __version(self):
-        version = None
-        try:
-            with open(
-                os.path.join(self.__path_lib_files, self.__info_file), "r"
-            ) as json_file:
-                version = json.load(json_file)
-        except IOError:
-            version = {"error": "cannot get info.json"}
-        return version
-
     async def initialize_before_start(self, app, loop):
         if self.__jobs is None:
             self.__jobs = Jobs(self.__logger)
@@ -114,7 +86,7 @@ class Runner:
             )
             self.__scheduler = Scheduler(self.__logger, self.__jobs, self.__nb, loop)
             self.__app.add_route(
-                SchedulerController.as_view(self.__logger, self.__scheduler),
+                SchedulerController.as_view(self.__scheduler),
                 f"/{t_scheduler}/<mode>",
             )
             self.__app.add_route(
@@ -172,7 +144,7 @@ class Runner:
         print("Start Runner", __version__)
         try:
             if os.environ.get("NAAS_SENTRY_DSN"):
-                self.__sentry = sentry_sdk.init(
+                sentry_sdk.init(
                     dsn=os.environ.get("NAAS_SENTRY_DSN"),
                     traces_sample_rate=1.0,
                     environment=escape_kubernet(self.__user),
